<?php

/**
 * Komfortkasse Order Class
 * in KK, an Order is an Array providing the following members:
 * number, date, email, customer_number, payment_method, amount, currency_code, exchange_rate, language_code
 * status: data type according to the shop system
 * delivery_ and billing_: _firstname, _lastname, _company, _street, _postcode, _city, _countrycode
 * products: an Array of item numbers
 * @version 1.2.1.10-hhg-multistore
 */

class Komfortkasse_Order {
	
	// return all order numbers that are "open" and relevant for tranfer to kk
	public static function getOpenIDs() {
	    global $registry;
		
		$ret = array ();
		
		$sql = "select orders_id from " . TABLE_ORDERS . " where orders_status in (" . Komfortkasse_Config::getConfig(Komfortkasse_Config::status_open) . ") and ( ";
		$paycodes = preg_split ('/,/', Komfortkasse_Config::getConfig(Komfortkasse_Config::payment_methods));	
		for($i=0; $i<count($paycodes);$i++) {
			$sql .= " payment_method like '" . $paycodes[$i] . "' ";
			if ($i < count($paycodes)-1) {
				$sql .= " or ";
			}
		}	
		$sql .= " )";
		$orders_q=$registry['db']->query($sql);
		
		while (!$orders_q->EOF) {
			$ret [] = $orders_q->fields ['orders_id'];
			$orders_q->MoveNext();
		}

		return $ret;
	}
	public static function getOrder($number) {
		// require_once DIR_WS_CLASSES . 'class.order.php';
	    global $registry;
		
		$order = new order ( $number, '', $registry);
		if (empty ( $number ) || empty ( $order )) {
			return null;
		}
		
		$total_q=$registry['db']->query("SELECT value FROM ".TABLE_ORDERS_TOTAL." where orders_id=" . $number . " and class='ot_total'");
		$total = $total_q->fields['value'];
		
		$lang_q=$registry['db']->query("SELECT l.code FROM ".TABLE_ORDERS." o join " . TABLE_LANGUAGES . " l on l.directory=o.language where o.orders_id=" . $number );
		$lang = $lang_q->fields['code'];
		
		$ret = array ();
		$ret ['number'] = $number;
		$ret ['date'] = date("d.m.Y", strtotime($order->info ['date_purchased']));
		$ret ['email'] = $order->customer['email_address'];
		$ret ['customer_number'] = $order->customer ['csID'];
		$ret ['payment_method'] = $order->info ['payment_method'];
		$ret ['amount'] = $total;
		$ret ['currency_code'] = $order->info ['currency'];
		$ret ['exchange_rate'] = $order->info ['currency_value'];
		$ret ['language_code'] = $lang . '-' . $order->billing ['country_iso_code_2'];
		$ret ['delivery_firstname'] = $order->delivery ['firstname'];
		$ret ['delivery_lastname'] = $order->delivery ['lastname'];
		$ret ['delivery_company'] = $order->delivery ['company'];
		$ret ['delivery_street'] = $order->delivery ['street_address'];
		$ret ['delivery_postcode'] = $order->delivery ['postcode'];
    	$ret ['delivery_city'] = $order->delivery ['city'];
    	$ret ['delivery_countrycode'] = $order->delivery ['country_iso_code_2'];
    	$ret ['billing_firstname'] = $order->billing ['firstname'];
		$ret ['billing_lastname'] = $order->billing ['lastname'];
		$ret ['billing_company'] = $order->billing ['company'];
		$ret ['billing_street'] = $order->billing ['street_address'];
		$ret ['billing_postcode'] = $order->billing ['postcode'];
		$ret ['billing_city'] = $order->billing ['city'];
		$ret ['billing_countrycode'] = $order->billing ['country_iso_code_2'];
		
		$order_products = $order->products;
		foreach ( $order_products as $product ) {
			if ($product ['model']) {
				$ret['products'][] = $product ['model'] ;
			} else {
				$ret ['products'] [] = $product ['name'];
			}
		}
		
		return $ret;
	}
	
	public static function updateOrder($order, $status, $callbackid) {
	    global $registry;
	    
	    $data = array(
	        'orders_status' => $status,
	        'last_modified' => 'now()'
	    );
	    $registry['db']->perform(TABLE_ORDERS, $data, 'update', "orders_id = '".$order['number']."'");
	    $data = array(
	            'orders_id' => $order['number'],
	            'orders_status_id' => $status,
	            'date_added' => 'now()',
	            'customer_notified' => '0',
	            'comments' => 'Komfortkasse ID '.$callbackid
	    );
		$registry['db']->perform(TABLE_ORDERS_STATUS_HISTORY, $data);
	}
}

?>